API docs for “spamfighter.rules”

# Package s.rules

Part of spamfighter View Source

Набор правил анализа сообщений СпамоБорца.

Module | analyze | Набор правил аналица текста сообщений
Module | frequency | Набор правил проверки текста сообщений на частоту
Module | log | Правила, управляющие логом сообщений.
Module | model | Правила, управляющие моделями.
Package | test | Тесты на `spamfighter.rules`.
Module | validate | Модуль содержащий правила проверки сообщений

From the __init__.py module:

Function | loadRules | Загрузить все правила СпамоБорца.

def loadRules(): (source)
Загрузить все правила СпамоБорца.